Learn R Programming

rapr (version 1.1.2)

get_rap_production16day_table: Query RAP 16-day Production Data

Description

Retrieves remotely sensed production estimates from the Rangeland Analysis Platform (RAP) using the production16dayV3 API endpoint. This function supports querying one or more spatial features (points, lines, or polygons) provided as a terra SpatVector in WGS84 longitude latitude ("EPSG:4326").

Usage

get_rap_production16day_table(
  aoi,
  year = NULL,
  mask = TRUE,
  nodata_flag = NA_real_
)

Value

A data.frame with 16-day production data including the following columns: "date" (production estimate date), "year" (production estimate year), "doy" (production estimate Julian day of year), "AFG" (Annual Forb and Grass production), "PFG" (Perennial Forb and Grass production), "HER" (Herbaceous production), "feature" (feature ID, row number from aoi)

Arguments

aoi

Area of Interest. A SpatVector object, or any spatial object that can be converted with terra::vect(). The AOI coordinates will be transformed to WGS84 longitude latitude ("EPSG:4326"). The AOI can be specified using point, line and polygon geometries. Each unique feature will be passed separately to the API. The result feature column contains the row index of the input feature from aoi.

year

integer. Optional. Numeric year or vector of years (1986 to last full year). Default: NULL returns all available years.

mask

logical. Exclude cropland, development, and water? Default: TRUE.

nodata_flag

numeric. Value to use for missing data. The API encodes "NODATA" as -99. Default: NA_real_ replaces -99 with NA.

Details

For each feature - year combination, a separate request is made to the RAP API, and results are returned as a combined data.frame. In the special case of year=NULL) default all available years are returned in a single query.

For more information on the API and data products, see the RAP API documentation: https://rangelands.app/support/71-api-documentation